==> fly-qdm_2.9.6.tar.xz: fly-qdm/dm_greet/ui_greeter/uigreeter.cpp <==
#include "uigreeter.h"

#include <QScreen>
#include <QGridLayout>
#include <QSet>

#include "themewidgetcreator.h"
#include "kgdialog.h"
#include "kdmshutdown.h"
#include "utils.h"
#include "greeterhandler.h"
#include "shutdownhandler.h"
#include "exceptions.h"
#include "stssettings.h"
#include "managers/greetermanagers.h"
#include "widgets/basethemewidget.h"
#include "managers/sessionsmanager.h"
#include "managers/usersmanager.h"
#include "managers/shutdownmanager.h"
#include "managers/virtualkeyboardmanager.h"
#include "managers/keyboardmanager.h"
#include "managers/connectionmanager.h"
#include "managers/consoleauthmanager.h"


UiGreeter::UiGreeter(const ThemeInfo& themeInfo, const SystemInfo& systemInfo, QScreen* screen) :
    FDialog(nullptr, false),
    m_systemInfo(systemInfo),
    m_themeInfo(themeInfo),
    m_greeterHandler(new GreeterHandler(systemInfo.dmSocket)),
    m_shutdownHandler(new ShutdownHandler(m_greeterHandler)),
    m_managers(nullptr),
    m_stsSettings(new StsSettings(systemInfo.stsFile, systemInfo.dname))
{
    connect(screen, &QScreen::geometryChanged,
            this, QOverload<const QRect&>::of(&UiGreeter::setGeometry));
    setGeometry(screen->geometry());
    setObjectName("greeterDialog");
}

UiGreeter::~UiGreeter()
{
    delete m_greeterHandler;
    delete m_shutdownHandler;
    delete m_stsSettings;
    if (m_managers) {
        delete m_managers;
    }
}

void UiGreeter::load()
{
    setupManagers();

    connect(m_greeterHandler, &GreeterHandler::successLogin,
            this, &UiGreeter::performSuccessLogin);

    if (m_systemInfo.loginPlugins.isEmpty()) {
        throw CommonException(tr("Login plugins is empty"));
    }

    EnvironmentData enviroment;
    enviroment.locale = m_systemInfo.locale;
    const auto mainThemeWidget = ThemeWidgetCreator::create(m_themeInfo, m_systemInfo.loginPlugins.first(), m_managers, enviroment);

    const auto layout = new QGridLayout();
    layout->setMargin(0);
    layout->addWidget(mainThemeWidget);
    setLayout(layout);
}

int UiGreeter::exec()
{
    m_greeterHandler->start();

    return FDialog::exec();
}

void UiGreeter::performSuccessLogin()
{
    done(ex_login);
}

void UiGreeter::restartXServer()
{
    done(EX_RESERVER_DPY);
}

void UiGreeter::exitConnection()
{
    done(EX_RESERVE);
}

void UiGreeter::showConsoleDialog()
{
   const auto sessions = fetchSessions(0); // TODO
    if (KDMConfShutdown(-1, sessions, SHUT_CONSOLE, QString()).exec()) {
        m_greeterHandler->handleConsoleLoginRequest();
    }
}

void UiGreeter::setupManagers()
{
    const auto localAuthManager = new LocalAuthManager();
    connect(m_greeterHandler, &GreeterHandler::loginFailed,
            localAuthManager, &LocalAuthManager::loginFailed);
    connect(m_greeterHandler, &GreeterHandler::successLogin,
            localAuthManager, &LocalAuthManager::successLogin);
    connect(localAuthManager, &LocalAuthManager::loginRequest,
            m_greeterHandler, &GreeterHandler::handleLoginRequest);


    const auto sessionsDescriptions = SessionReader::readDirs(m_systemInfo.sessionsDirs);
    const auto sessionManager = new SessionsManager(sessionsDescriptions);
    connect(sessionManager, &SessionsManager::setNextSessionTypeRequest,
            m_greeterHandler, &GreeterHandler::setSessionType);

    UserInfo::Filter usersFilter;
    usersFilter.showUsers = m_systemInfo.showUsers;
    usersFilter.lowUserId = m_systemInfo.lowUserId;
    usersFilter.highUserId = m_systemInfo.highUserId;
    usersFilter.users = m_systemInfo.users;
    usersFilter.noUsers = m_systemInfo.noUsers;
    usersFilter.showRoot = m_systemInfo.showRoot;
    usersFilter.sortUsers = m_systemInfo.sortUsers;
    const auto users = UserInfo::getUserList(usersFilter);
    const auto icons = UserIcon::getUserIcons(m_systemInfo.faceDir);
    const auto usersManager = new UsersManager(users, icons, m_stsSettings);

    const auto shutdownManager = new ShutdownManager();
    connect(shutdownManager, &ShutdownManager::shutdownRequest,
            m_shutdownHandler, &ShutdownHandler::handleShutdown);

    const auto virtualKeyboardManager = new VirtualKeyboardManager(m_systemInfo.vkbCommand, m_systemInfo.xdpi);

    const auto keyboardManager = new KeyboardManager(XKeyboard::instance());

    ConnectionManager::ConnectionData connectionData;
    connectionData.allowClose = m_systemInfo.allowClose;
    connectionData.isReserve = m_systemInfo.isReserve;
    connectionData.isLocal = m_systemInfo.isLocal;
    const auto sessions = GreeterHandler::getDisplaySessions(lstPassive | lstTTY);
    const auto connectionManager = new ConnectionManager(connectionData, sessions);
    connect(connectionManager, &ConnectionManager::restartXServerRequest,
            this, &UiGreeter::restartXServer);
    connect(connectionManager, &ConnectionManager::exitConnectionRequest,
            this, &UiGreeter::exitConnection);
    connect(connectionManager, &ConnectionManager::switchDisplayRequest,
            m_greeterHandler, &GreeterHandler::switchDisplay);

    const auto consoleAuthManager = new ConsoleAuthManager(m_systemInfo.hasConsole);
    connect(consoleAuthManager, &ConsoleAuthManager::consoleLoginRequest,
            this, &UiGreeter::showConsoleDialog);

    m_managers = new GreeterManagers({localAuthManager,
                                      sessionManager,
                                      usersManager,
                                      shutdownManager,
                                      virtualKeyboardManager,
                                      keyboardManager,
                                      connectionManager,
                                      consoleAuthManager});
}

==> fly-qdm_2.11.6.tar.xz: fly-qdm/dm_greet/ui_greeter/uigreeter.cpp <==
#include "uigreeter.h"

#include <QScreen>
#include <QGridLayout>
#include <QSet>

#include "themewidgetcreator.h"
#include "kgdialog.h"
#include "kdmshutdown.h"
#include "utils.h"
#include "greeterhandler.h"
#include "shutdownhandler.h"
#include "exceptions.h"
#include "stssettings.h"
#include "managers/greetermanagers.h"
#include "widgets/basethemewidget.h"
#include "managers/sessionsmanager.h"
#include "managers/usersmanager.h"
#include "managers/shutdownmanager.h"
#include "managers/virtualkeyboardmanager.h"
#include "managers/keyboardmanager.h"
#include "managers/connectionmanager.h"
#include "managers/consoleauthmanager.h"


UiGreeter::UiGreeter(const ThemeInfo& themeInfo, const SystemInfo& systemInfo, QScreen* screen) :
    FDialog(nullptr, false),
    m_systemInfo(systemInfo),
    m_themeInfo(themeInfo),
    m_greeterHandler(new GreeterHandler(systemInfo.dmSocket)),
    m_shutdownHandler(new ShutdownHandler(m_greeterHandler)),
    m_managers(nullptr),
    m_stsSettings(new StsSettings(systemInfo.stsFile, systemInfo.dname))
{
    connect(screen, &QScreen::geometryChanged,
            this, QOverload<const QRect&>::of(&UiGreeter::setGeometry));
    setGeometry(screen->geometry());
    setObjectName("greeterDialog");
}

UiGreeter::~UiGreeter()
{
    delete m_greeterHandler;
    delete m_shutdownHandler;
    delete m_stsSettings;
    if (m_managers) {
        delete m_managers;
    }
}

void UiGreeter::load()
{
    setupManagers();

    connect(m_greeterHandler, &GreeterHandler::successLogin,
            this, &UiGreeter::performSuccessLogin);

    if (m_systemInfo.loginPlugins.isEmpty()) {
        throw CommonException(tr("Login plugins is empty"));
    }

    EnvironmentData enviroment;
    enviroment.locale = m_systemInfo.locale;
    const auto mainThemeWidget = ThemeWidgetCreator::create(m_themeInfo, m_systemInfo.loginPlugins.first(), m_managers, enviroment);

    const auto layout = new QGridLayout();
    layout->setMargin(0);
    layout->addWidget(mainThemeWidget);
    setLayout(layout);
}

int UiGreeter::exec()
{
    m_greeterHandler->start();

    return FDialog::exec();
}

void UiGreeter::performSuccessLogin()
{
    done(ex_login);
}

void UiGreeter::restartXServer()
{
    done(EX_RESERVER_DPY);
}

void UiGreeter::exitConnection()
{
    done(EX_RESERVE);
}

void UiGreeter::showConsoleDialog()
{
   const auto sessions = fetchSessions(0); // TODO
    if (KDMConfShutdown(-1, sessions, SHUT_CONSOLE, QString()).exec()) {
        m_greeterHandler->handleConsoleLoginRequest();
    }
}

void UiGreeter::setupManagers()
{
    const auto localAuthManager = new LocalAuthManager();
    connect(m_greeterHandler, &GreeterHandler::loginFailed,
            localAuthManager, &LocalAuthManager::loginFailed);
    connect(m_greeterHandler, &GreeterHandler::successLogin,
            localAuthManager, &LocalAuthManager::successLogin);
    connect(localAuthManager, &LocalAuthManager::loginRequest,
            m_greeterHandler, &GreeterHandler::handleLoginRequest);
    connect(m_greeterHandler, &GreeterHandler::passwordChangeRequestedByPam,
            localAuthManager, &LocalAuthManager::passwordChangeRequested);
    connect(localAuthManager, &LocalAuthManager::newPasswordInsertionCompleted,
            m_greeterHandler, &GreeterHandler::onNewPasswordInsertionCompleted);
    connect(localAuthManager, &LocalAuthManager::newPasswordInsertionRejected,
            m_greeterHandler, &GreeterHandler::onNewPasswordInsertionRejected);
    connect(m_greeterHandler, &GreeterHandler::pamErrorReceived,
            localAuthManager, &LocalAuthManager::pamErrorReceived);


    const auto sessionsDescriptions = SessionReader::readDirs(m_systemInfo.sessionsDirs);
    const auto sessionManager = new SessionsManager(sessionsDescriptions);
    connect(sessionManager, &SessionsManager::setNextSessionTypeRequest,
            m_greeterHandler, &GreeterHandler::setSessionType);

    UserInfo::Filter usersFilter;
    usersFilter.showUsers = m_systemInfo.showUsers;
    usersFilter.lowUserId = m_systemInfo.lowUserId;
    usersFilter.highUserId = m_systemInfo.highUserId;
    usersFilter.users = m_systemInfo.users;
    usersFilter.noUsers = m_systemInfo.noUsers;
    usersFilter.showRoot = m_systemInfo.showRoot;
    usersFilter.sortUsers = m_systemInfo.sortUsers;
    const auto users = UserInfo::getUserList(usersFilter);
    const auto icons = UserIcon::getUserIcons(m_systemInfo.faceDir);
    const auto usersManager = new UsersManager(users, icons, m_stsSettings, m_systemInfo.showTokenUsers, m_systemInfo.userList);

    const auto shutdownManager = new ShutdownManager();
    connect(shutdownManager, &ShutdownManager::shutdownRequest,
            m_shutdownHandler, &ShutdownHandler::handleShutdown);

    const auto virtualKeyboardManager = new VirtualKeyboardManager(m_systemInfo.vkbCommand, m_systemInfo.xdpi);

    const auto keyboardManager = new KeyboardManager(XKeyboard::instance());

    ConnectionManager::ConnectionData connectionData;
    connectionData.allowClose = m_systemInfo.allowClose;
    connectionData.isReserve = m_systemInfo.isReserve;
    connectionData.isLocal = m_systemInfo.isLocal;
    const auto sessions = GreeterHandler::getDisplaySessions(lstPassive | lstTTY);
    const auto connectionManager = new ConnectionManager(connectionData, sessions);
    connect(connectionManager, &ConnectionManager::restartXServerRequest,
            this, &UiGreeter::restartXServer);
    connect(connectionManager, &ConnectionManager::exitConnectionRequest,
            this, &UiGreeter::exitConnection);
    connect(connectionManager, &ConnectionManager::switchDisplayRequest,
            m_greeterHandler, &GreeterHandler::switchDisplay);

    const auto consoleAuthManager = new ConsoleAuthManager(m_systemInfo.hasConsole);
    connect(consoleAuthManager, &ConsoleAuthManager::consoleLoginRequest,
            this, &UiGreeter::showConsoleDialog);

    m_managers = new GreeterManagers({localAuthManager,
                                      sessionManager,
                                      usersManager,
                                      shutdownManager,
                                      virtualKeyboardManager,
                                      keyboardManager,
                                      connectionManager,
                                      consoleAuthManager});
}
